part of 'x_http_client.dart';

/// An HTTP Exception that occurs when [XHttpClient.send] a request, and the response [statusCode] is not 2xx.
/// This instance also represents the actual HTTP [Response] that has failed
class XHTTPException implements Exception, Response {
  final Response _response;

  const XHTTPException(this._response);

  @override
  String get body => _response.body;

  @override
  Uint8List get bodyBytes => _response.bodyBytes;

  @override
  int? get contentLength => _response.contentLength;

  @override
  Map<String, String> get headers => _response.headers;

  @override
  bool get isRedirect => _response.isRedirect;

  @override
  bool get persistentConnection => _response.persistentConnection;

  @override
  String? get reasonPhrase => _response.reasonPhrase;

  @override
  BaseRequest? get request => _response.request;

  @override
  int get statusCode => _response.statusCode;

  @override
  String toString() =>
      'XHTTPException: $statusCode $reasonPhrase ${contentLength == null ? '' : '($contentLength bytes)'}';
}
